% =========================================================================
% Title       : Generate Channel According to Specified Model
% File        : channel.m
% -------------------------------------------------------------------------
% Description :
%   Wrapper for channel models. This file only includes a simple n-Tap
%   channel model. The TGn channel models have been omitted due to 
%   copyright issues. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   24-feb-10  1.1      studer  TGn channel models removed 
%   10-aug-06  1.0      studer  adapted from ofdm_sim environment
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

function [HN]=channel(TxRx)

  HN = zeros(TxRx.Nrx,TxRx.Ntx,TxRx.N);
    
  switch(TxRx.Channel.Model)
    case 'TGn', % -- TGN channel models
      error('TGn models not supported due to Copyright issues.')
    case 'Tap', % -- tap channel model      
      % -- generate channels in time domain
      Ht = zeros(TxRx.Nrx,TxRx.Ntx,TxRx.N); % Mt x Mr x time
      Ht(:,:,1:TxRx.Channel.Ntaps) = sqrt(0.5/TxRx.Channel.Ntaps)*(randn(TxRx.Nrx,TxRx.Ntx,TxRx.Channel.Ntaps) ...
                                     + 1i*randn(TxRx.Nrx,TxRx.Ntx,TxRx.Channel.Ntaps) );

      % -- convert to frequency domain                                        
      for kk = 1:TxRx.Nrx
        for ll = 1:TxRx.Ntx
          HN(kk,ll,:) = fftshift(fft(squeeze(Ht(kk,ll,:))));
        end
      end       
      
    otherwise,
      error('No valid TxRx.Channel.Model in channel.m')
  end 
  
return
