% =========================================================================
% Title       : Wrapper for Channel Decoders
% File        : decoder.m
% -------------------------------------------------------------------------
% Description :
%   This file performs (de-)puncturing and calls the chosen channel
%   decoder. Note that this version only contains a max-log BCJR
%   implementation written in Mex/Matlab. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   17-sep-07  1.3      studer  simplified/cleanup for student projects
%   19-sep-06  1.2      studer  removed some channel decoders
%   17-aug-06  1.1      studer  added BCJR as benchmark
%   07-jun-06  1.0      studer  partially adopted from ofdm_sim
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

function [LLR_A1,LLR_P1,binary_data_hat] = decoder(TxRx,LLR_E1)

  % -- de-interleaving
  LLR_A2(1,TxRx.Code.InterleaverPerm) = LLR_E1;   
          
  % -- de-puncturing
  LLR_A2_punctured=zeros(1,2*length(LLR_A2)*TxRx.Code.Rate);    
  LLR_A2_punctured(TxRx.Code.Puncturing.Index) = LLR_A2;

  % -- channel decoding
  switch (TxRx.Decoder.Type)       
    case 'BCJR', % -- max-log BJCR algorithm (fast Matlab/mex C-implementation)
      [LLR_D2_punctured,binary_data_hat] = BCJR(TxRx.Code.trellis,LLR_A2_punctured); 
    otherwise,
      error('No valid TxRx.Decoder.Type in decoder.m')
  end
  
  % -- perform puncturing
  LLR_D2 = LLR_D2_punctured(TxRx.Code.Puncturing.Index);

  % -- output extrinsic information
  LLR_E2 = LLR_D2 - LLR_A2;
  
  % -- interleaving for next iteration
  LLR_A1 = LLR_E2(1,TxRx.Code.InterleaverPerm); 
  LLR_P1 = LLR_D2(1,TxRx.Code.InterleaverPerm);  
  
return
