% =========================================================================
% Title       : Example Script for Simulator
% File        : ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD.m
% -------------------------------------------------------------------------
% Description :
%   Starts a simulation using the SISO STS-SD algorithm in a 1-Tap
%   channel.
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   28-feb-10  1.0      studer  file created
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

function ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD(RunID)

  % -- simulation setup
  TxRx.Sim.name = 'ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD';
  TxRx.Sim.MaxPER = 1000;        % Maximum required PER 
  TxRx.Sim.nr_of_packets = 1000; % Number of packets
  TxRx.Sim.nr_of_symbols = 4;    % Number of OFDM symbols per packet
  TxRx.Sim.SNR_dB_list = [10:2:30];    
  
  % -- system configuration
  TxRx.Modulation_order = 4; % Modulation scheme: BPSK (1), QPSK (2), 16-QAM (4), 64-QAM (6)
  TxRx.Nrx = 4;              % Rx Antennas
  TxRx.Ntx = 4;              % Tx Antennas
  TxRx.N = 128;              % Nr. of subcarriers
  TxRx.ToneMap=[-58:-54,-52:-26,-24:-12,-10:-2,2:10,12:24,26:52,54:58]+63+1; % 40MHz IEEE 802.1n 
  TxRx.Iterations = 4;       % Nr. of iterations     

  % -- choose detector and decoder type 
  TxRx.Detector.Preprocessing = 'SQRD';  % 'off', 'QRD', 'SQRD', 'MMSEQRD', 'MMSESQRD'
  TxRx.Detector.Type = 'SISO_STS_SD';    % 'SISO_MMSE_PIC', 'SISO_STS_SD'  
  TxRx.Detector.Clipping = 'legacy'; % 'legacy', 'exact'
  TxRx.Detector.MaxLLR = 0.4;
  TxRx.Decoder.Type = 'BCJR';            % 'BCJR', 'BCJRopt'
  
  % -- code and decoder properties
  TxRx.Code.K = 7;                   % Constraint Length
  TxRx.Code.generators = [133  171]; % Generator Polynomial      
  TxRx.Code.Rate = 5/6;              % code rates '1/2','3/4','2/3','5/6'
  
  % -- channel model
  TxRx.Channel.Model = 'Tap'; % 'Tap' (uniform profile)
  TxRx.Channel.Ntaps = 1; 
  
  % -- start simulation
  err_sim(TxRx,RunID);

return
  
