% =========================================================================
% Title       : Example Script for Matlab Error-Rate Plots
% File        : err_plot.m
% -------------------------------------------------------------------------
% Description :
%   Simple example of a packet error-rate (PER) plot. The simulation
%   results are collected using the consolidate.m command file. This
%   simulation shows a simple comparison between a 4-tap and a 1-tap
%   channel model for the SISO MMSE PIC algorithm and the SISO STS-SD.  
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   11-nov-08  1.2      studer  file created, cleanup
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

clear all
clc

% =========================================================================

% -- collect 10 files
number = 10;

% -- load simulation data and consolidate
MMSE_I1 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_MMSE_PIC_I1',number);
MMSE_I2 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_MMSE_PIC_I2',number);
MMSE_I4 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_MMSE_PIC_I4',number);
%
STS_I1 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_STS_SD_I1',number);
STS_I2 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_STS_SD_I2',number);
STS_I4 = consolidate('ERR_4x4_16QAM_Tap4_BCJR_SISO_STS_SD_I4',number);

% =========================================================================

% -- show plot
figure(1)
semilogy(MMSE_I1.TxRx.Sim.SNR_dB_list,MMSE_I1.PER,'bo-','Linewidth',2)
hold on
semilogy(STS_I1.TxRx.Sim.SNR_dB_list,STS_I1.PER,'gp-','Linewidth',2)
% additional plots
semilogy(MMSE_I2.TxRx.Sim.SNR_dB_list,MMSE_I2.PER,'bo-','Linewidth',2)
semilogy(MMSE_I4.TxRx.Sim.SNR_dB_list,MMSE_I4.PER,'bo-','Linewidth',2)
%
semilogy(STS_I2.TxRx.Sim.SNR_dB_list,STS_I2.PER,'gp-','Linewidth',2)
semilogy(STS_I4.TxRx.Sim.SNR_dB_list,STS_I4.PER,'gp-','Linewidth',2)
%
hold off
axis([10 30 1e-3 1])
grid on
set(gca,'FontSize',12)
xlabel('SNR [dB]','FontSize',12)
ylabel('PER','FontSize',12)
legend('SISO MMSE PIC','SISO STS-SD',3)
title('4-Tap Channel')
% -- write eps file to disk
% print -deps 'plots/4tap.eps'

% -- load simulation data and consolidate
MMSE_I1 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_MMSE_PIC_I1',number);
MMSE_I2 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_MMSE_PIC_I2',number);
MMSE_I4 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_MMSE_PIC_I4',number);
%
STS_I1 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD_I1',number);
STS_I2 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD_I2',number);
STS_I4 = consolidate('ERR_4x4_16QAM_Tap1_BCJR_SISO_STS_SD_I4',number);

% =========================================================================

% -- show plot
figure(2)
semilogy(MMSE_I1.TxRx.Sim.SNR_dB_list,MMSE_I1.PER,'bo-','Linewidth',2)
hold on
semilogy(STS_I1.TxRx.Sim.SNR_dB_list,STS_I1.PER,'gp-','Linewidth',2)
% additional plots
semilogy(MMSE_I2.TxRx.Sim.SNR_dB_list,MMSE_I2.PER,'bo-','Linewidth',2)
semilogy(MMSE_I4.TxRx.Sim.SNR_dB_list,MMSE_I4.PER,'bo-','Linewidth',2)
%
semilogy(STS_I2.TxRx.Sim.SNR_dB_list,STS_I2.PER,'gp-','Linewidth',2)
semilogy(STS_I4.TxRx.Sim.SNR_dB_list,STS_I4.PER,'gp-','Linewidth',2)
%
hold off
axis([10 30 1e-3 1])
grid on
set(gca,'FontSize',12)
xlabel('SNR [dB]','FontSize',12)
ylabel('PER','FontSize',12)
legend('SISO MMSE PIC','SISO STS-SD',3)
title('1-Tap Channel')
% -- write eps file to disk
% print -deps 'plots/1tap.eps'