% =========================================================================
% Title       : Consolidate Simulation results
% File        : consolidate.m
% -------------------------------------------------------------------------
% Description :
%   Collects at most "number" simulation results and computes avereage
%   error rates and complexities. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   10-aug-06  1.0      studer  adapted from ofdm_sim environment
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

function Out = consolidate(filename,number);
  disp(sprintf('consolidate %s ...',filename));
  k = 0;
  for i=1:number
    fullname = ['results/',filename,'_',num2str(i-1),'.mat'];
    % -- check whether file exists
    if exist(fullname)>0
      tmp = load(fullname);
      if k==0
        ptype = tmp;
        complexity = ptype.Results.complexity;
        BER = ptype.Results.BER;
        SER = ptype.Results.SER;
        PER = ptype.Results.PER;
        NrOfSimPackets = ptype.Results.NrOfSimPackets;
      else
        complexity = complexity + tmp.Results.complexity;
        BER = BER + tmp.Results.BER;
        SER = SER + tmp.Results.SER;
        PER = PER + tmp.Results.PER;
        NrOfSimPackets = NrOfSimPackets + tmp.Results.NrOfSimPackets;
      end
      k=k+1;
    end
  end
  % -- average and compute output
  ptype.Results.complexity = complexity/k;
  ptype.Results.BER = BER/k;
  ptype.Results.SER = SER/k;
  ptype.Results.PER = PER/k; 
  ptype.Results.NrOfSimPackets = NrOfSimPackets;
  disp(sprintf('%i packets simulated.\n',NrOfSimPackets));
  Out = ptype.Results;
return
