% =========================================================================
% Title       : MIMO transmitter
% File        : tx.m
% -------------------------------------------------------------------------
% Description :
%   This file generates random bits, applies forward error-correction with
%   a convolutional encoder (note: convenc reqiures communication toolbox).
%   Furthermore, interleaving and modulation is performed and the symbol
%   vectors are transmitted over the channel matrices (without noise).
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   14-sep-07  1.0      studer  file created
% -------------------------------------------------------------------------
%   (C) 2006-2010 Communication Theory Group                      
%   ETH Zurich, 8092 Zurich, Switzerland                               
%   Author: Dr. Christoph Studer (e-mail: studerc@nari.ee.ethz.ch)     
% =========================================================================

function [data_bin,xN] = tx(TxRx,HN)

  % -- generate random bits and apply forward error correction   
  data_bin = round(rand(1,ceil(TxRx.Ntx*TxRx.Nused*TxRx.Modulation_order*TxRx.Code.Rate)));
  data_bin(1,[size(data_bin,2)+1-(TxRx.Code.K-1)-TxRx.Code.PADbits:size(data_bin,2)]) = 0;
  data_bin_coded(1,:) = convenc(data_bin(1,:),TxRx.Code.trellis); % requires communication toolbox
  
  % -- puncturing
  data_bin_punctured = data_bin_coded(TxRx.Code.Puncturing.Index);
  
  % -- interleaving
  data_bin_stream = data_bin_punctured(1,TxRx.Code.InterleaverPerm);

  % -- distribute across antennas
  data_bin_coded = reshape(data_bin_stream,TxRx.Nused*TxRx.Modulation_order,TxRx.Ntx).';  
    
  % -- modulation (prepare symbol vectors)   
  for ntx=1:TxRx.Ntx
    tmp = reshape(data_bin_coded(ntx,:),TxRx.Modulation_order,TxRx.Nused);
    tmp_dec = bi2de(tmp.').';
    sN(ntx,:) = TxRx.Constellations_norm(tmp_dec+1);
  end

  % -- transmit over the used OFDM tones
  for n=1:TxRx.Nused
    xN(:,n) = HN(:,:,TxRx.ToneMap(n))*sN(:,n);
  end 
      
return
  